const icons = {
    play: require('./assets/Play.svg'),
    stop: require('./assets/Stop.svg'),
    logo: require('./assets/Scratch-Logo.svg'),
    soundPlaying: require('./assets/Playing-Sound.svg'),
    soundMuted: require('./assets/Mute.svg'),
    fullscreen: require('./assets/Fullscreen.svg'),
    unfullscreen: require('./assets/Unfullscreen.svg')
};

const loaderStyle = require(
    '!!css-loader/locals?modules&camelCase&localIdentName=[name]_[local]_[hash:base64:5]' +
    '!postcss-loader!./js/loader/loader.css');
const loaderHtml = require('./js/loader/loader.html.js');

module.exports = `<!doctype html>
<html>
  <head>
    <meta charset="UTF-8">
    <meta name="apple-mobile-web-app-capable" content="yes">
    <!--
    We've found this viewport tag to be important for avoiding some layout
    bugs on mobile. Please include it as is.
    -->
    <meta name="viewport" content="initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0, width=device-width">
    <!-- Styling for the player, virtual buttons and the page around it -->
  </head>
  <body class="sw-body">
    <!-- <div style="height: 10em; width: 100%"></div> -->
    <!-- stage-container class is currently required by the player for appending virtual buttons UI -->
    <div class="stage-container">
      <div class="controls-container">
        <button class="play-button"><img src="${icons.play}" alt="Play"></button>
        <button class="stop-button"><img src="${icons.stop}" alt="Stop"></button>
        <a href="https://scratch.mit.edu/" class="logo-link" ><img class="logo-link" src="${icons.logo}" alt="Scratch"></a>
        <button class="sound-button will-mute">
          <img class="playing" src="${icons.soundPlaying}" alt="Toggle Mute">
          <img class="muted" src="${icons.soundMuted}" alt="Toggle Mute">
        </button>
        <button class="fullscreen-button will-fullscreen">
          <img class="fullscreen" src="${icons.fullscreen}" alt="Toggle Fullscreen">
          <img class="unfullscreen" src="${icons.unfullscreen}" alt="Toggle Fullscreen">
        </button>
      </div>
      <!--
      This canvas element loads the Scratch project.

      The scratch-stage id is required by the player for getting the correct canvas element and initializing the player.

      data-source may be set to load a scratch project at a given url. If a number is passed data-path may be used to
      find the project.

      data-path may be set to load assets from a directory at a given url.

      data-playing
        - auto [default]
        - play
        - stop

      data-fullscreen
        - auto [default]
        - true
        - false

      data-fullscreen-state - fullscreen-state is not an option. Instead its
          the readable value of whether the player is fullscreen.
        - true - true when the player is fullscreen
        - false - false when the player is not fullscreen

      data-volume
        - 100 [default]
        - [number from 0 to 100]
        - mute

      data-max-width
        - auto [default]
        - [number]

      data-max-height
        - auto [default]
        - [number]

      data-max-dpi
        - auto [default]
        - [number]
      -->
      <canvas class="stage" id="scratch-stage" width="480" height="360"
        data-source="assets/playground/project.json"
        data-path="assets/playground/"
        data-playing="stop"
        data-fullscreen=""
        data-volume=""
        data-max-width=""
        data-max-height=""
        data-max-dpi=""></canvas>
      ${loaderHtml(loaderStyle)}
    </div>
    <!-- JavaScript that creates the player in the canvas element and adds virtual buttons -->
  </body>
</html>`;
